
##################################################
#	Bent Nielsen
#	16 April 2020
#
#	Now-casting COVID-19 fatalities: track by death-date (not by report-date)
#	SM Bird and B Nielsen
#
#	Uses data NHS data for England from
#	https://www.england.nhs.uk/statistics/statistical-work-areas/covid-19-daily-deaths/
#	along with some older data.
#
#	Uses package apc
#
##################################################
#	Rolling Age-Cohort analysis
##################################################

##################################################
#	Parameters, user defined
##################################################
#	selection of data and number of now-casts
n.rep	<- 7	# how report periods to use in each analysis? 7 would be the last week of reports.
n.anal	<- 17	# how many rolling analysis. Choose >1 for recursive evaluation


##################################################
##	AC analysis
##################################################

n.anal.trunc <- min(n.anal,data.sub$per.max-n.rep) 		
tab.out <- matrix(NA,nrow=n.anal.trunc,ncol=6)

for(i in 1:n.anal.trunc)
{
	per.cut.upper	<- i-1
	per.cut.lower	<- data.sub$per.max - n.rep - per.cut.upper
	data.ac <- apc.data.list.subset(data.sub,0,0,per.cut.lower,per.cut.upper,per.cut.lower,0,suppress.warning=suppress.warning)
	tab.out[i,] <- apc.fit.table(data.ac,"od.poisson.response")[3,]
}	

rownames(tab.out)	<- colnames(data.sub$response)[ncol(data.sub$response)+1-1:n.anal.trunc]
colnames(tab.out) 	<- colnames(apc.fit.table(data.ac,"od.poisson.response"))

tab.out.text <-	paste("Test for AC against APC using triangle with up to ",n.rep," days of reporting delay. ",
						"Date in row name indicates last data-of-death in sub-sample. ",
						"For instance, '13 Apr' uses data for 7-13 Apr when triangle has dimension 7. ", sep="")

print(tab.out.text)
print(tab.out)





#data.ac <- apc.data.list.subset(data.sub,0,0,0,0,12,0)
#fit.ac <- apc.fit.model(data.ac,"od.poisson.response","AC")
#apc.forecast.ac(fit.ac,quantiles=quantiles)$response.forecast.coh
#apc.fit.table(data.ac,"od.poisson.response")


