##################################################
#	Bent Nielsen
#	15 April 2020
#
#	Now-casting COVID-19 fatalities: track by death-date (not by report-date)
#	SM Bird and B Nielsen
#
#	Uses data NHS data for England from
#	https://www.england.nhs.uk/statistics/statistical-work-areas/covid-19-daily-deaths/
#
#	along with some older data.

##################################################
#	CHOOSE REGION BEFORE THIS PROGRAM
#	options are
#		England
#		London
##################################################

##################################################
#	Parameters, user defined
##################################################

##################################################
#	Parameters relating to reading of data file
label		<- "CovidReportingNHS_England"	# label for dataset
#drop.col	<- 25							# drop 25 columns to drop data before 25 March
drop.col.after.25.march	<- 1 				# drop columns/cohorts/date-of-death after 25 March									

##################################################
#	Read data using
#	openxlsx
##################################################
#	use this for reading data in xlsx format
#	this package allows row names														   
#   read xlsx file
if(region=="England")
{	
	data.daily	<- read.xlsx(paste(drive.data,datafile,sep=""), sheet="Daily_Announced",colNames=TRUE,rowNames=TRUE,sep.names=" ")      
	data.total	<- read.xlsx(paste(drive.data,datafile,sep=""), sheet="Total_Announced",colNames=TRUE,rowNames=TRUE,sep.names=" ")
	data.older	<- read.xlsx(paste(drive.data,datafile,sep=""), sheet="Older_Data",	   colNames=TRUE,rowNames=TRUE,sep.names=" ")
}	else
		data.total	<- read.xlsx(paste(drive.data,datafile,sep=""), sheet=region,colNames=TRUE,rowNames=TRUE,sep.names=" ")
#	read weekdays	
data.weekd	<- read.xlsx(paste(drive.data,datafile,sep=""), sheet="Weekdays",	   colNames=TRUE,rowNames=TRUE,sep.names=" ")

##################################################
#	Convert to matrix/vector format
##################################################

#   convert from data.frame format to matrix / vector
#	common conversions
m.total	<- as.matrix(data.total)
v.weekd	<- 			 data.weekd$Weekday
v.holid	<- 			 data.weekd$Holiday
#	for England
if(region=="England")
{
	m.daily	<- as.matrix(data.daily)
	m.older	<- as.matrix(data.older)
}	else
	{
		m.total.lag	<- m.total[1:(nrow(m.total)-1),]
		m.total.lag[is.na(m.total.lag)] <- 0	
		m.daily	<- m.total[2:nrow(m.total),] - m.total.lag
	}

#	drop oldest dates-of-death in PC format
m.daily <- m.daily[,(25+1):ncol(m.daily)]
m.total <- m.total[,(25+1):ncol(m.total)]

#	for England
# 	paste older data and daily data
if(region=="England")
{
	m.older	<- cbind(m.older,matrix(NA,nrow=nrow(m.older),ncol=ncol(m.daily)-ncol(m.older)))
	colnames(m.older) <- colnames(m.daily)
	m.daily	<- rbind(m.older[1:(nrow(m.older)-1),],m.daily)
}	

##################################################
#   convert m.daily to apc.data.list format as a PC matrix
#	then convert to AC matrix
##################################################
#	rows	= period	= announcement day
#	cols	= colhor	= day-of-death
#	age 	= delay
#	coh1 	= -6 		This is for 25 March = -6 April	for England	and not England
#	per1 	= -5		This is for 26 March = -5 April for England
#	per1 	=  5		This is for 			5 April for not England
coh1	<- -6
if(region=="England") 	{	per1	<- -5	} 	else 	per1	<- 5

data		<- apc.data.list(response=m.daily,data.format="PC",label=label,per1=per1,coh1=coh1,time.adjust=0)
#	drop rows with NAs when going from PC to AC format
#	drop drop.col.after.25.march initial cohorts
if(region=="England")	{	age.cut.lower	<- ncol(m.daily)-1
			}	else 		age.cut.lower	<- per1-coh1
data.sub	<- apc.data.list.subset(data,age.cut.lower,0,0,0,drop.col.after.25.march,0,suppress.warning=suppress.warning)
m.total.sub	<- m.total[,seq(1+drop.col.after.25.march,ncol(m.total))]
if(region=="England")	{	data.sub$per1	<- data$per1+drop.col.after.25.march	
			}	else 		data.sub$per1	<- data$per1
i.keep <- (drop.col.after.25.march+1):ncol(m.daily)
colnames(data.sub$response) <- colnames(m.daily)[i.keep]
i.keep <- (drop.col.after.25.march+1):length(v.weekd)
v.weekd <- v.weekd[i.keep]
v.holid <- v.holid[i.keep]
##	to check dates run
##	apc.plot.data.level(data)
##	apc.plot.data.level(data.sub)
#