##################################################
#	Bent Nielsen
#	16 April 2020
#
#	Now-casting COVID-19 fatalities: track by death-date (not by report-date)
#	SM Bird and B Nielsen
#
#	Uses data NHS data for England from
#	https://www.england.nhs.uk/statistics/statistical-work-areas/covid-19-daily-deaths/
#	along with some older data.
#
#	Uses package apc
#
##################################################
#	Plot of delay distribution.
#	This can be used to show that the delay distribution for
#	date-of-death for 5-14 April is quite stable
#	whereas delay distribution for 4 April is quite different
##################################################

##################################################
#	Parameters, user defined
##################################################
n.delay		<- 10		# how much delay/age to consider on x-axis? 10 is good choice
n.coh		<- 13		# how many cohorts/date-of-death to consider? 4 April is messy
log.scale	<- TRUE
# lower limit on y-axis.  If too small plot gets messy. 3 is good choice
if(region=="England")	{ y.lower	<- exp(3) }	else	{ y.lower <- exp(2) }

##################################################
##	Plot data delay matrix
##################################################

#	log transformations
if(log.scale)	{ m.data.plot	<- log(data.sub$response)	}	else	{ m.data.plot	<-     data.sub$response }
if(log.scale)	{ y.lower	<- log(y.lower) 				}

#	plot
end	<- nrow(m.data.plot) 
leg <- colnames(m.data.plot)[end]
col <- 1
x		<- 1:end
xlim	<- c(1,n.delay)
ylim	<- c(y.lower,max(m.data.plot,na.rm=TRUE))
main	<- paste(region,": Delay distribution",sep="")

if(l.save.plot.as.svg)
	svg(filename=paste(drive.plot,"FigDelay",region,date,".svg",sep=""),width=5, height=5, pointsize=12)

if(log.scale) 	{	ylab 	<- "log cases reported"	} 	else	{	ylab 	<- "cases reported"	}	
plot(x,m.data.plot[,end],col=col,xlim=xlim,ylim=ylim,xlab="reporting delay in days",ylab=ylab,pch=4,type="p",main=main)
for(col in 2:n.coh)
{
	y	<- m.data.plot[,end+1-col]
	lines(x,y,col=col,pch=4)
#	points(x,m.data.plot[,end+1-col],col=col,pch=4)
	leg <- c(leg, colnames(m.data.plot)[end+1-col])
}
legend("topright",legend=leg,col=1:col,lty=1,title="date-of-death")

if(l.save.plot.as.svg)
	dev.off()
	